@@ -66,51 +66,14 @@ get_weather <- function(station, year, month = 1:12, dir = NULL) {
     dir_is_null <- FALSE
   }
   
-  weather_raw <- purrr::map(station, 
+  weather <- purrr::map(station, 
                             get_weather_for_station, 
                             year = year,
                             dir = dir, 
-                            month_and_day_range = month_and_day_range) %>%
+                            month_and_day_range = month_and_day_range,
+                            month = month) %>%
     dplyr::bind_rows()
   
-  # tidy the data
-  weather <- weather_raw %>%
-    # rename some columns
-    dplyr::rename(origin = station, 
-                  time = valid, 
-                  temp = tmpf, 
-                  dewp = dwpf, 
-                  humid = relh,
-                  wind_dir = drct, 
-                  wind_speed = sknt, 
-                  wind_gust = gust,
-                  precip = p01i, 
-                  pressure = mslp, 
-                  visib = vsby,
-                  feels_like = feel) %>%
-    # get rid of the metadata column
-    dplyr::select(-metar) %>%
-    # mutate some new useful columns
-    dplyr::mutate(time = as.POSIXct(strptime(time, "%Y-%m-%d %H:%M")),
-                  wind_speed = as.numeric(wind_speed) * 1.15078, # convert to mpg
-                  wind_gust = as.numeric(wind_speed) * 1.15078,
-                  year = as.integer(year),
-                  month = as.integer(lubridate::month(time)),
-                  day = lubridate::mday(time),
-                  hour = lubridate::hour(time),
-                  time_hour = ISOdatetime(year, month, day, hour, 0, 0)) %>%
-    # filter to only relevant rows - necessary for discontinuous month ranges
-    dplyr::filter(month %in% !!month) %>%
-    # remove duplicates / incompletes
-    dplyr::group_by(origin, month, day, hour) %>%
-    dplyr::filter(dplyr::row_number() == 1) %>%
-    dplyr::ungroup() %>%
-    # reorder columns to match the original dataset
-    dplyr::select(origin, year, month, day, hour, temp, dewp, 
-                  humid, wind_dir, wind_speed, wind_gust, precip,
-                  pressure, visib, time_hour)
-    
-  
   # save the data if the user supplied a directory
   if (!dir_is_null) {
     save(weather, file = paste0(dir, "/weather.rda"), compress = "xz")
